package com.sd.business.service.in.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.sd.business.entity.in.dto.AddAllotDto;
import com.sd.business.entity.in.dto.InOutStorageDto;
import com.sd.business.entity.in.dto.InOutStorageSelectDto;
import com.sd.business.entity.in.emums.InDetailTypeEnum;
import com.sd.business.entity.in.emums.InOutTypeEnum;
import com.sd.business.entity.in.emums.OutDetailTypeEnum;
import com.sd.business.entity.in.po.InOutStorage;
import com.sd.business.entity.in.po.InOutStorageBom;
import com.sd.business.entity.in.po.InOutStorageDetails;
import com.sd.business.entity.in.vo.InOutStorageVo;
import com.sd.business.entity.warehouse.po.Warehouse;
import com.sd.business.mapper.in.InOutStorageMapper;
import com.sd.business.service.in.InOutStorageBomService;
import com.sd.business.service.in.InOutStorageDetailsService;
import com.sd.business.service.in.InOutStorageService;
import com.sd.business.service.inventory.InventoryService;
import com.sd.business.util.CodeEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * <p>
 * 出入库 服务实现类
 * </p>
 *
 * @author
 * @since 2023-07-03
 */
@Service
public class InOutStorageServiceImpl extends ServiceImpl<InOutStorageMapper, InOutStorage> implements InOutStorageService {
    //单价逻辑还没做完,先拿个常量顶着
    public static final BigDecimal UNITPRICE = BigDecimal.TEN;

    @Autowired
    private InOutStorageBomService inOutStorageBomService;

    @Autowired
    private InOutStorageDetailsService detailsService;

    @Autowired
    private InventoryService inventoryService;

    @Override
    public Page<InOutStorageVo> getPage(InOutStorageSelectDto dto) {
        IWrapper<InOutStorage> wrapper = getWrapper();
        wrapper.orderByDesc("ios", InOutStorage::getId);
        wrapper.eq("ios", InOutStorage::getType, dto.getType());
        wrapper.like("ios", InOutStorage::getCode, dto.getCode());
        wrapper.eq("ios", InOutStorage::getDepartmentId, dto.getDepartmentId());
        wrapper.like("w", Warehouse::getName, dto.getWarehouseName());
        wrapper.eq("ios", InOutStorage::getDetailType, dto.getDetailType());
        wrapper.ge("ios", InOutStorage::getCreateTime, dto.getBeginTime());
        wrapper.le("ios", InOutStorage::getCreateTime, dto.getEndTime());

        Page<InOutStorageVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    @Override
    public InOutStorageVo detail(Long id) {
        InOutStorage InOutStorage = this.getById(id);
        InOutStorageVo result = BeanUtil.toBean(InOutStorage, InOutStorageVo.class);
        return result;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(InOutStorageDto inOutStorageDto) {

        List<InOutStorageBom> inOutStorageBomList = inOutStorageDto.getInOutStorageBomList();

        if (InOutTypeEnum.getInOutType(inOutStorageDto.getType()).equals(InOutTypeEnum.IN)) {
            // 赋值入库单号
            inOutStorageDto.setCode(CodeEnum.IN_CODE.getCode());
            // 更新库存
            inventoryService.in(inOutStorageDto.getDepartmentId(), inOutStorageDto.getWarehouseId(), inOutStorageBomList);
        } else {
            // 赋值出库单号
            inOutStorageDto.setCode(CodeEnum.OUT_CODE.getCode());
            // 更新库存
            inventoryService.out(inOutStorageDto.getDepartmentId(), inOutStorageDto.getWarehouseId(), inOutStorageBomList);
        }
        this.save(inOutStorageDto);

        inOutStorageBomList.forEach(item -> item.setInOutStorageId(inOutStorageDto.getId()));
        List<InOutStorageDetails> detailsList = new ArrayList<>();
        //进行for循环
        for (InOutStorageBom bom : inOutStorageBomList) {
            if (inOutStorageDto.getType().equals(1)){
                //创建InOutStorageDetails对象
                InOutStorageDetails details = new InOutStorageDetails();
                //将数据进行填充
                details.setInUnitPrice(UNITPRICE);
                details.setQuantity(bom.getQuantity());
                details.setWarehouseId(inOutStorageDto.getWarehouseId());
                details.setBomSpecId(bom.getBomSpecId());
                details.setDepartmentId(inOutStorageDto.getDepartmentId());

                detailsList.add(details);
            }
        }
        //进行数据的添加
        detailsService.saveBatch(detailsList);
        inOutStorageBomService.saveBatch(inOutStorageBomList);

    }

    @Override
    public void edit(InOutStorageDto inOutStorageDto) {
        this.updateById(inOutStorageDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addAllot(AddAllotDto dto) {
        long allotFlag = IdWorker.getId();

        InOutStorageDto inStorageDto = BeanUtil.toBean(dto, InOutStorageDto.class);
        inStorageDto.setWarehouseId(dto.getInWarehouseId());
        inStorageDto.setType(InOutTypeEnum.IN.getKey());
        inStorageDto.setDetailType(InDetailTypeEnum.ALLOT.getKey());
        inStorageDto.setAllotFlag(allotFlag);
        add(inStorageDto);

        InOutStorageDto outStorageDto = BeanUtil.toBean(dto, InOutStorageDto.class);
        outStorageDto.setWarehouseId(dto.getOutWarehouseId());
        outStorageDto.setType(InOutTypeEnum.OUT.getKey());
        outStorageDto.setDetailType(OutDetailTypeEnum.ALLOT.getKey());
        outStorageDto.setAllotFlag(allotFlag);
        add(outStorageDto);
    }

}
