package com.sd.wln.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ruoyi.common.constant.StatusConstant;
import com.ruoyi.common.core.domain.BaseIdPo;
import com.sd.business.entity.bom.bo.BomBo;
import com.sd.business.entity.bom.po.BomSpec;
import com.sd.business.entity.department.po.Department;
import com.sd.business.entity.order.enums.OrderStatusEnum;
import com.sd.business.entity.order.po.OrderInfo;
import com.sd.business.entity.order.po.OrderPackageBom;
import com.sd.business.entity.order.po.OrderSku;
import com.sd.business.entity.order.po.OrderSkuBom;
import com.sd.business.entity.price.po.PriceBillingStandardDetail;
import com.sd.business.entity.sku.po.SkuSpec;
import com.sd.business.entity.sku.po.SkuSpecLink;
import com.sd.business.service.bom.BomSpecService;
import com.sd.business.service.order.OrderPackageBomService;
import com.sd.business.service.order.OrderService;
import com.sd.business.service.order.OrderSkuBomService;
import com.sd.business.service.order.OrderSkuService;
import com.sd.business.service.sku.SkuSpecLinkService;
import com.sd.business.service.sku.SkuSpecService;
import com.sd.wln.context.OrderContext;
import com.sd.wln.service.WlnOrderService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Service
public class WlnOrderServiceImpl implements WlnOrderService {

    @Autowired
    private PlatformTransactionManager platformTransactionManager;

    @Autowired
    private TransactionDefinition transactionDefinition;

    @Autowired
    private OrderService orderService;

    @Autowired
    private OrderSkuService orderSkuService;

    @Autowired
    private OrderSkuBomService orderSkuBomService;

    @Autowired
    private OrderPackageBomService orderPackageBomService;

    @Autowired
    private SkuSpecService skuSpecService;

    @Autowired
    private SkuSpecLinkService skuSpecLinkService;

    @Autowired
    private BomSpecService bomSpecService;

    @Override
    public void syncOrder() {

        OrderContext context = new OrderContext();

        // 万里牛订单若为0，结束同步任务
        List<JSONObject> wlnOrderList = context.getWlnOrderList();
        if (ObjectUtil.isEmpty(wlnOrderList)) {
            return;
        }

        // 循环万里牛订单
        for (JSONObject wlnOrder : wlnOrderList) {

            // 创建订单
            OrderInfo orderInfo = createOrder(context, wlnOrder);

            // 没有创建订单实体，跳过同步
            if (orderInfo == null) {
                continue;
            }

            // 判断订单是否存在与数据库中,若订单存在且订单信息被修改，则添加到更新订单数组
            boolean existOrder = existOrder(context, orderInfo);

            // 若订单是否存在与数据库中，跳过以下保存订单逻辑
            if (existOrder) {
                continue;
            }

            // 添加订单到上下文
            addOrder(context, wlnOrder, orderInfo);

        }

        // 计算订单价格
        setOrderPrice(context);

        // 保存或更新数据
        saveOrUpdateOrder(context);

    }

    /**
     * 订单是否存在,若订单存在且订单信息被修改，则添加到更新订单数组
     */
    private boolean existOrder(OrderContext context, OrderInfo orderInfo) {
        Map<String, OrderInfo> orderMap = context.getOrderMap();
        List<OrderInfo> updateOrderList = context.getUpdateOrderList();

        // 如果订单存在于数据库,且订单状态改变,执行update
        OrderInfo oldOrderInfo = orderMap.get(orderInfo.getWlnUid());

        if (oldOrderInfo != null) {
            if (ObjectUtil.notEqual(oldOrderInfo.getWlnStatus(), orderInfo.getWlnStatus())
                    || ObjectUtil.notEqual(oldOrderInfo.getWlnModifyTimestamp(), orderInfo.getWlnModifyTimestamp())
                    || ObjectUtil.notEqual(DateUtil.formatDateTime(oldOrderInfo.getWlnApproveTime()), DateUtil.formatDateTime(orderInfo.getWlnApproveTime()))
                    || ObjectUtil.notEqual(DateUtil.formatDateTime(oldOrderInfo.getWlnPrintTime()), DateUtil.formatDateTime(orderInfo.getWlnPrintTime()))
                    || ObjectUtil.notEqual(oldOrderInfo.getWlnStorageCode(), orderInfo.getWlnStorageCode())
                    || ObjectUtil.notEqual(oldOrderInfo.getDepartmentId(), orderInfo.getDepartmentId())) {

                OrderInfo updateOrder = new OrderInfo();
                updateOrder.setId(oldOrderInfo.getId());
                updateOrder.setWlnStatus(orderInfo.getWlnStatus());
                updateOrder.setWlnModifyTime(orderInfo.getWlnModifyTime());
                updateOrder.setWlnModifyTimestamp(orderInfo.getWlnModifyTimestamp());
                updateOrder.setWlnApproveTime(orderInfo.getWlnApproveTime());
                updateOrder.setWlnPrintTime(orderInfo.getWlnPrintTime());
                updateOrder.setWlnStorageCode(orderInfo.getWlnStorageCode());
                updateOrder.setDepartmentId(orderInfo.getDepartmentId());
                updateOrderList.add(updateOrder);

            }
            return true;
        }

        return false;
    }

    /**
     * 创建订单
     */
    private OrderInfo createOrder(OrderContext context, JSONObject wlnOrder) {

        // 仓库编号
        String storageCode = wlnOrder.getString("storage_code");

        // 部门实体
        Department department = context.getDepartmentMap().get(storageCode);

        // 未匹配到部门id
        if (department == null) {
            log.error("未知仓库code：{}", storageCode);
            return null;
        }

        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setId(IdWorker.getId());
        orderInfo.setSource(2);
        orderInfo.setCode(wlnOrder.getString("tp_tid"));
        orderInfo.setWlnCode(wlnOrder.getString("trade_no"));
        orderInfo.setWlnStatus(wlnOrder.getInteger("process_status"));
        orderInfo.setWlnUid(wlnOrder.getString("uid"));
        orderInfo.setWlnModifyTime(wlnOrder.getDate("modify_time"));
        orderInfo.setWlnModifyTimestamp(wlnOrder.getLong("modify_time"));
        orderInfo.setWlnCreateTime(wlnOrder.getDate("create_time"));
        orderInfo.setWlnApproveTime(wlnOrder.getDate("approve_time"));
        orderInfo.setWlnPrintTime(wlnOrder.getDate("print_time"));
        orderInfo.setWlnStorageCode(wlnOrder.getString("storage_code"));
        orderInfo.setDeliveryTime(DateUtil.offsetDay(orderInfo.getWlnCreateTime(), 1));
        orderInfo.setProvince(wlnOrder.getString("province"));
        orderInfo.setCity(wlnOrder.getString("city"));
        orderInfo.setCounty(wlnOrder.getString("district"));
        orderInfo.setDetailedAddress(wlnOrder.getString("address"));
        orderInfo.setPostcode(wlnOrder.getString("zip"));
        orderInfo.setDepartmentId(department.getId());
        orderInfo.setRemark(wlnOrder.getString("remark"));
        orderInfo.setTaxRate(new BigDecimal("10.00"));
        orderInfo.setTag("0");
        orderInfo.setSettlementStatus(1);

        StringBuilder builder = new StringBuilder();
        // 订单来源平台
        if (wlnOrder.containsKey("source_platform")) {
            builder.append(wlnOrder.getString("source_platform"));
        }
        // 店铺名称
        if (wlnOrder.containsKey("shop_name")) {
            builder.append("_").append(wlnOrder.getString("shop_name"));
        }
        orderInfo.setCommercePlatform(builder.toString());

        // 订单状态
        if (orderInfo.getWlnStatus() == 10 || orderInfo.getWlnStatus() == 11 || orderInfo.getWlnStatus() == 12) {
            orderInfo.setStatus(OrderStatusEnum.EXCEPTION.getKey());
        } else if (Objects.equals(department.getOrderMode(), "2")) {
            orderInfo.setStatus(OrderStatusEnum.STOCK_PREPARATION.getKey());
        } else {
            orderInfo.setStatus(OrderStatusEnum.UNDER_REVIEW.getKey());
        }

        return orderInfo;
    }

    /**
     * 创建订单sku
     */
    private OrderSku createOrderSku(JSONObject wlnOrderSku, OrderInfo orderInfo, SkuSpec skuSpec) {
        OrderSku orderSku = new OrderSku();
        orderSku.setId(IdWorker.getId());
        orderSku.setWlnSkuId(wlnOrderSku.getString("sys_goods_uid"));
        orderSku.setWlnSkuSpecId(wlnOrderSku.getString("sys_spec_uid"));
        orderSku.setWlnSkuName(wlnOrderSku.getString("oln_sku_name"));
        orderSku.setOrderId(orderInfo.getId());
        orderSku.setSkuId(skuSpec.getSkuId());
        orderSku.setSkuSpecId(skuSpec.getId());
        orderSku.setBomSpecId(skuSpec.getBomSpecId());
        orderSku.setQuantity(wlnOrderSku.getBigDecimal("size"));
        orderSku.setPrintType(1);
        orderSku.setStockPreparationStatus(StatusConstant.NO);
        return orderSku;
    }

    /**
     * 创建订单包材
     */
    private List<OrderSkuBom> createOrderSkuBoom(List<OrderSku> orderSkuList, Map<Long, BomSpec> bomSpecMap, List<SkuSpecLink> list) {
        if (ObjectUtil.isEmpty(list)) {
            return Collections.emptyList();
        }

        Map<Long, List<SkuSpecLink>> skuSpecLinkMap = list.stream().collect(Collectors.groupingBy(SkuSpecLink::getSkuSpecId));

        return orderSkuList.stream().flatMap(orderSku -> {
            List<SkuSpecLink> skuSpecLinkList = skuSpecLinkMap.getOrDefault(orderSku.getSkuSpecId(), Collections.emptyList());
            return skuSpecLinkList.stream().map(item -> {
                OrderSkuBom orderSkuBom = new OrderSkuBom();
                orderSkuBom.setId(IdWorker.getId());
                orderSkuBom.setOrderId(orderSku.getOrderId());
                orderSkuBom.setOrderSkuId(orderSku.getId());
                orderSkuBom.setBomSpecId(item.getBomSpecId());
                orderSkuBom.setQuantity(item.getQuantity());
                BomSpec bomSpec = bomSpecMap.get(item.getBomSpecId());
                if (bomSpec == null) {
                    orderSkuBom.setUnitPrice(BigDecimal.ZERO);
                } else {
                    orderSkuBom.setUnitPrice(ObjectUtil.defaultIfNull(bomSpec.getInternalSellingPrice(), BigDecimal.ZERO));
                }
                return orderSkuBom;
            });
        }).collect(Collectors.toList());
    }

    /**
     * 创建订单包装
     */
    private List<OrderPackageBom> createOrderPackageBomList(List<OrderSku> orderSkuList, Map<Long, BomSpec> bomSpecMap, List<SkuSpecLink> list) {
        if (ObjectUtil.isEmpty(list)) {
            return Collections.emptyList();
        }

        Map<Long, List<SkuSpecLink>> skuSpecLinkMap = list.stream().collect(Collectors.groupingBy(SkuSpecLink::getSkuSpecId));
        Map<Long, OrderPackageBom> orderPackageBomMap = new HashMap<>();

        // 循环订单sku规格
        for (OrderSku orderSku : orderSkuList) {
            List<SkuSpecLink> skuSpecLinkList = skuSpecLinkMap.get(orderSku.getSkuSpecId());
            if (ObjectUtil.isEmpty(skuSpecLinkList)) {
                continue;
            }

            for (SkuSpecLink skuSpecLink : skuSpecLinkList) {
                Long bomSpecId = skuSpecLink.getBomSpecId();
                OrderPackageBom orderPackageBom = orderPackageBomMap.computeIfAbsent(bomSpecId, item -> {
                    OrderPackageBom tempOrderPackageBom = new OrderPackageBom();
                    tempOrderPackageBom.setOrderId(orderSku.getOrderId());
                    tempOrderPackageBom.setBomSpecId(bomSpecId);
                    tempOrderPackageBom.setQuantity(BigDecimal.ZERO);
                    BomSpec bomSpec = bomSpecMap.get(bomSpecId);
                    if (bomSpec == null) {
                        tempOrderPackageBom.setCostPrice(BigDecimal.ZERO);
                        tempOrderPackageBom.setInternalSellingPrice(BigDecimal.ZERO);
                    } else {
                        tempOrderPackageBom.setCostPrice(ObjectUtil.defaultIfNull(bomSpec.getCostPrice(), BigDecimal.ZERO));
                        tempOrderPackageBom.setInternalSellingPrice(ObjectUtil.defaultIfNull(bomSpec.getInternalSellingPrice(), BigDecimal.ZERO));
                    }
                    return tempOrderPackageBom;
                });
                orderPackageBom.setQuantity(orderPackageBom.getQuantity().add(orderSku.getQuantity().multiply(skuSpecLink.getQuantity())));
            }
        }

        return new ArrayList<>(orderPackageBomMap.values());
    }

    /**
     * 添加订单到上下文
     */
    private void addOrder(OrderContext context, JSONObject wlnOrder, OrderInfo orderInfo) {
        Map<String, SkuSpec> skuSpecMap = context.getSkuSpecMap();

        List<OrderSku> orderSkuList = new ArrayList<>();

        // 是否添加
        boolean isAdd = true;

        // 创建订单sku
        for (JSONObject wlnOrderSku : wlnOrder.getJSONArray("orders").toJavaList(JSONObject.class)) {

            // 订单明细未匹配到sku规格，跳过次订单同步
            String sysSpecUid = wlnOrderSku.getString("sys_spec_uid");

            // sku规格信息
            SkuSpec skuSpec = skuSpecMap.get(sysSpecUid);

            if (skuSpec == null) {
                isAdd = false;
                log.error("没有通过万里牛sys_spec_uid: {} 找到sku规格", sysSpecUid);
                break;
            }

            // 创建订单sku
            OrderSku orderSku = createOrderSku(wlnOrderSku, orderInfo, skuSpec);
            orderSkuList.add(orderSku);

        }

        if (!isAdd) {
            return;
        }

        // 订单关联
        List<Long> skuSpecIdList = orderSkuList.stream().map(OrderSku::getSkuSpecId).collect(Collectors.toList());
        List<SkuSpecLink> list = skuSpecLinkService.list(q -> q
                .in(SkuSpecLink::getSkuSpecId, skuSpecIdList)
                .eq(SkuSpecLink::getDepartmentId, orderInfo.getDepartmentId()));

        // 跳过type区分包材和快递包装
        Map<Integer, List<SkuSpecLink>> map = list.stream().collect(Collectors.groupingBy(SkuSpecLink::getType));

        // 根据sku规格id获取bomId和bom规格id
        List<Long> bomSpecIdList = list.stream().map(SkuSpecLink::getBomSpecId).filter(Objects::nonNull).distinct().collect(Collectors.toList());
        Map<Long, BomSpec> bomSpecMap;
        if (bomSpecIdList.size() == 0) {
            bomSpecMap = Collections.emptyMap();
        } else {
            bomSpecMap = bomSpecService.mapKEntity(BaseIdPo::getId, q -> q.in(BaseIdPo::getId, bomSpecIdList));
        }

        // 获取订单sku包材
        List<OrderSkuBom> orderSkuBomList = createOrderSkuBoom(orderSkuList, bomSpecMap, map.get(1));

        // 获取订单sku快递包装
        List<OrderPackageBom> orderPackageBomList = createOrderPackageBomList(orderSkuList, bomSpecMap, map.get(2));

        context.getSaveOrderList().add(orderInfo);
        context.getSaveOrderSkuList().addAll(orderSkuList);
        context.getSaveOrderSkuBomList().addAll(orderSkuBomList);
        context.getOrderPackageBomList().addAll(orderPackageBomList);

    }

    /**
     * 赋值订单价格
     */
    private void setOrderPrice(OrderContext context) {

        List<OrderInfo> saveOrderList = context.getSaveOrderList();
        List<OrderSku> saveOrderSkuList = context.getSaveOrderSkuList();
        List<OrderSkuBom> saveOrderSkuBomList = context.getSaveOrderSkuBomList();
        Map<String, SkuSpec> skuSpecMap = context.getSkuSpecMap();
        Map<Long, List<PriceBillingStandardDetail>> priceBillingStandardMap = context.getPriceBillingStandardMap();

        if (saveOrderList.size() == 0) {
            return;
        }

        // 根据sku规格id获取bom规格
        List<Long> bomSpecIdList = saveOrderSkuList.stream().map(OrderSku::getBomSpecId).collect(Collectors.toList());
        Map<Long, BomBo> bomBoMap = skuSpecService.getBomBoByIdList(bomSpecIdList);

        // 订单明细
        Map<Long, List<OrderSku>> orderSkuGroup = saveOrderSkuList.stream().collect(Collectors.groupingBy(OrderSku::getOrderId));

        for (OrderInfo orderInfo : saveOrderList) {

            orderInfo.setTotalAmount(BigDecimal.ZERO);
            orderInfo.setProductTotalAmount(BigDecimal.ZERO);
            orderInfo.setCustomProcessingFee(BigDecimal.ZERO);
            orderInfo.setLssueFee(BigDecimal.ZERO);
            orderInfo.setDeliveryMaterialsFee(BigDecimal.ZERO);
            orderInfo.setPackingLabor(BigDecimal.ZERO);
            orderInfo.setPackagingMaterialCost(BigDecimal.ZERO);

            // 加工计费标准
            Long departmentId = orderInfo.getDepartmentId();
            List<PriceBillingStandardDetail> priceBillingStandardDetailList = priceBillingStandardMap.get(departmentId);

            // 订单明细
            List<OrderSku> itemOrderSkuList = orderSkuGroup.get(orderInfo.getId());

            for (OrderSku orderSku : itemOrderSkuList) {

                // 赋值单价
                assignedUnitPrice(orderSku, bomBoMap);

                // 赋值包材费
                assignedPackagingMaterialCost(orderSku, saveOrderSkuBomList);

                // 赋值其他价格
                assignedOtherPrice(orderSku, bomBoMap, priceBillingStandardDetailList, skuSpecMap);

                // 添加订单金额
                addOrderInfoPrice(orderInfo, orderSku);

            }

        }
    }

    /**
     * 赋值单价
     */
    private void assignedUnitPrice(OrderSku orderSku, Map<Long, BomBo> bomBoMap) {
        BomBo bomBo = bomBoMap.get(orderSku.getBomSpecId());
        if (bomBo != null) {
            orderSku.setUnitPrice(ObjectUtil.defaultIfNull(bomBo.getInternalSellingPrice(), BigDecimal.ZERO));
        } else {
            orderSku.setUnitPrice(BigDecimal.ZERO);
        }
    }

    /**
     * 赋值包材费
     */
    private void assignedPackagingMaterialCost(OrderSku orderSku, List<OrderSkuBom> saveOrderSkuBomList) {
        BigDecimal packagingMaterialCost = saveOrderSkuBomList.stream()
                .filter(item -> Objects.equals(item.getOrderSkuId(), orderSku.getId()))
                .map(item -> item.getUnitPrice().multiply(item.getQuantity()))
                .reduce(BigDecimal.ZERO, BigDecimal::add);

        orderSku.setPackagingMaterialCost(packagingMaterialCost);
    }

    /**
     * 赋值其他价格
     */
    private void assignedOtherPrice(OrderSku orderSku, Map<Long, BomBo> bomBoMap,
                                    List<PriceBillingStandardDetail> priceBillingStandardDetailList,
                                    Map<String, SkuSpec> skuSpecMap) {

        orderSku.setCustomProcessingFee(BigDecimal.ZERO);
        orderSku.setLssueFee(BigDecimal.ZERO);
        orderSku.setDeliveryMaterialsFee(BigDecimal.ZERO);
        orderSku.setPackingLabor(BigDecimal.ZERO);

        // 报价规则列表
        if (ObjectUtil.isEmpty(priceBillingStandardDetailList)) {
            return;
        }

        // 没绑定bom规格，不赋值价格
        BomBo bomBo = bomBoMap.get(orderSku.getBomSpecId());
        if (bomBo == null) {
            return;
        }

        // 如果bom规格不为主材，不赋值价格
        if (ObjectUtil.notEqual(bomBo.getClassifyParentId(), 1L)) {
            return;
        }

        for (PriceBillingStandardDetail priceBillingStandardDetail : priceBillingStandardDetailList) {

            String chargeItem = priceBillingStandardDetail.getChargeItem();
            BigDecimal chargePrice = ObjectUtil.defaultIfNull(priceBillingStandardDetail.getChargePrice(), BigDecimal.ZERO);

            switch (chargeItem) {
                case "40":
                    orderSku.setPackingLabor(chargePrice);
                    break;
                case "50":
                    orderSku.setLssueFee(chargePrice);
                    break;
                case "60":
                    orderSku.setDeliveryMaterialsFee(chargePrice);
                    break;
                default:
                    SkuSpec skuSpec = skuSpecMap.get(orderSku.getWlnSkuSpecId());
                    if (skuSpec != null
                            && Objects.equals(chargeItem, skuSpec.getMachinedPanel())
                            && orderSku.getQuantity().compareTo(priceBillingStandardDetail.getSectionMin()) >= 0
                            && orderSku.getQuantity().compareTo(priceBillingStandardDetail.getSectionMax()) < 0) {
                        orderSku.setCustomProcessingType(chargeItem);
                        orderSku.setCustomProcessingFee(chargePrice);
                    }
            }
        }
    }

    /**
     * 添加订单价格
     */
    private void addOrderInfoPrice(OrderInfo orderInfo, OrderSku orderSku) {
        BigDecimal quantity = orderSku.getQuantity();

        BigDecimal productTotalAmount = quantity.multiply(orderSku.getUnitPrice());
        BigDecimal customProcessingFee = quantity.multiply(orderSku.getCustomProcessingFee());
        BigDecimal lssueFee = quantity.multiply(orderSku.getLssueFee());
        BigDecimal deliveryMaterialsFee = quantity.multiply(orderSku.getDeliveryMaterialsFee());
        BigDecimal packingLabor = quantity.multiply(orderSku.getPackingLabor());
        BigDecimal packagingMaterialCost = quantity.multiply(orderSku.getPackagingMaterialCost());
        BigDecimal totalAmount = productTotalAmount
                .add(customProcessingFee)
                .add(lssueFee)
                .add(deliveryMaterialsFee)
                .add(packingLabor)
                .add(packagingMaterialCost);

        orderInfo.setProductTotalAmount(orderInfo.getProductTotalAmount().add(productTotalAmount));
        orderInfo.setCustomProcessingFee(orderInfo.getCustomProcessingFee().add(customProcessingFee));
        orderInfo.setLssueFee(orderInfo.getLssueFee().add(lssueFee));
        orderInfo.setDeliveryMaterialsFee(orderInfo.getDeliveryMaterialsFee().add(deliveryMaterialsFee));
        orderInfo.setPackingLabor(orderInfo.getPackingLabor().add(packingLabor));
        orderInfo.setPackagingMaterialCost(orderInfo.getPackagingMaterialCost().add(packagingMaterialCost));
        orderInfo.setTotalAmount(orderInfo.getTotalAmount().add(totalAmount));
    }

    /**
     * 保存或更新数据
     */
    private void saveOrUpdateOrder(OrderContext context) {

        List<OrderInfo> saveOrderList = context.getSaveOrderList();
        List<OrderInfo> updateOrderList = context.getUpdateOrderList();
        List<OrderSku> saveOrderSkuList = context.getSaveOrderSkuList();
        List<OrderSkuBom> saveOrderSkuBomList = context.getSaveOrderSkuBomList();
        List<OrderPackageBom> orderPackageBomList = context.getOrderPackageBomList();

        // 开启事务
        TransactionStatus transactionStatus = platformTransactionManager.getTransaction(transactionDefinition);

        try {

            if (saveOrderList.size() > 0) {
                orderService.saveBatch(saveOrderList);
            }
            if (updateOrderList.size() > 0) {
                orderService.updateBatchById(updateOrderList);
            }
            if (saveOrderSkuList.size() > 0) {
                orderSkuService.saveBatch(saveOrderSkuList);
            }
            if (saveOrderSkuBomList.size() > 0) {
                orderSkuBomService.saveBatch(saveOrderSkuBomList);
            }
            if (orderPackageBomList.size() > 0) {
                orderPackageBomService.saveBatch(orderPackageBomList);
            }

            // 提交事务
            platformTransactionManager.commit(transactionStatus);

        } catch (Exception e) {

            log.error("同步订单失败", e);

            // 回滚事务
            platformTransactionManager.rollback(transactionStatus);

        }
    }

}
